@@ -4,4 +4,4 @@ from .__private.elements import \
     EventGenerator, EventListener, \
     EventSource, EventAnalyzer, EventSink, \
     TriggererEventSource, TriggerableEventSource, TriggerableEventBatchSource
-from .__private.modlue import PipelineModule
+from .__private.pipeline import Pipeline
